summaryrefslogtreecommitdiff
path: root/tools/binman/ftest.py
diff options
context:
space:
mode:
Diffstat (limited to 'tools/binman/ftest.py')
-rw-r--r--tools/binman/ftest.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/tools/binman/ftest.py b/tools/binman/ftest.py
index ccbaf39cbf..32014ea8d9 100644
--- a/tools/binman/ftest.py
+++ b/tools/binman/ftest.py
@@ -76,7 +76,7 @@ FSP_M_DATA = b'fsp_m'
FSP_S_DATA = b'fsp_s'
FSP_T_DATA = b'fsp_t'
ATF_BL31_DATA = b'bl31'
-ATF_BL32_DATA = b'bl32'
+TEE_OS_DATA = b'this is some random tee OS data'
SCP_DATA = b'scp'
TEST_FDT1_DATA = b'fdt1'
TEST_FDT2_DATA = b'test-fdt2'
@@ -179,7 +179,7 @@ class TestFunctional(unittest.TestCase):
TestFunctional._MakeInputFile('compress', COMPRESS_DATA)
TestFunctional._MakeInputFile('compress_big', COMPRESS_DATA_BIG)
TestFunctional._MakeInputFile('bl31.bin', ATF_BL31_DATA)
- TestFunctional._MakeInputFile('bl32.bin', ATF_BL32_DATA)
+ TestFunctional._MakeInputFile('tee-pager.bin', TEE_OS_DATA)
TestFunctional._MakeInputFile('scp.bin', SCP_DATA)
# Add a few .dtb files for testing
@@ -3674,10 +3674,10 @@ class TestFunctional(unittest.TestCase):
data = self._DoReadFile('169_atf_bl31.dts')
self.assertEqual(ATF_BL31_DATA, data[:len(ATF_BL31_DATA)])
- def testPackBl32(self):
- """Test that an image with an ATF BL32 binary can be created"""
- data = self._DoReadFile('170_atf_bl32.dts')
- self.assertEqual(ATF_BL32_DATA, data[:len(ATF_BL32_DATA)])
+ def testPackTeeOs(self):
+ """Test that an image with a TEE binary can be created"""
+ data = self._DoReadFile('188_tee_os.dts')
+ self.assertEqual(TEE_OS_DATA, data[:len(TEE_OS_DATA)])
def testPackScp(self):
"""Test that an image with an SCP binary can be created"""